@@ -3,6 +3,7 @@
 # This file only contains a selection of the most common options. For a full list see
 # the documentation: https://www.sphinx-doc.org/en/master/usage/configuration.html
 
+import os
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
@@ -10,8 +11,8 @@ if TYPE_CHECKING:
 
 # -- Project information ---------------------------------------------------------------
 
-project = '"MESSAGEix models"'
-copyright = "2021, IIASA Energy, Climate, and Environment (ECE) Program"
+project = "MESSAGEix-GLOBIOM tools"
+copyright = "2020–2021, IIASA Energy, Climate, and Environment (ECE) Program"
 author = "IIASA Energy, Climate, and Environment (ECE) Program"
 
 
@@ -81,11 +82,18 @@ extlinks = {
 
 # -- Options for sphinx.ext.intersphinx ------------------------------------------------
 
+# For message-data, see: https://docs.readthedocs.io/en/stable/guides
+# /intersphinx.html#intersphinx-with-private-projects
+_token = os.environ.get("RTD_TOKEN_MESSAGE_DATA", "")
+
 intersphinx_mapping = {
     "genno": ("https://genno.readthedocs.io/en/stable", None),
     "ixmp": ("https://docs.messageix.org/projects/ixmp/en/latest/", None),
     "message-ix": ("https://docs.messageix.org/en/latest/", None),
-    "m-data": ("https://docs.messageix.org/projects/global/en/latest/", None),
+    "m-data": (
+        f"https://{_token}:@docs.messageix.org/projects/models-internal/en/latest/",
+        None,
+    ),
     "pandas": ("https://pandas.pydata.org/pandas-docs/stable/", None),
     "pytest": ("https://docs.pytest.org/en/stable/", None),
     "python": ("https://docs.python.org/3/", None),
