@@ -2,11 +2,12 @@ import logging
 
 import pandas as pd
 import pytest
+from message_ix import make_df
 from message_ix.testing import make_dantzig
 from pandas.testing import assert_frame_equal
 from sdmx.model import Code
 
-from message_ix_models import ScenarioInfo
+from message_ix_models import ScenarioInfo, Spec
 from message_ix_models.model.structure import get_codes
 
 
@@ -81,6 +82,19 @@ class TestScenarioInfo:
         assert 1963 == info.y0
         assert [1963, 1964, 1965] == info.Y
 
+    def test_repr(self):
+        si = ScenarioInfo()
+        si.set["foo"] = [1, 2, 3]
+        assert "<ScenarioInfo: 3 code(s) in 1 set(s)>" == repr(si)
+
+    def test_update(self):
+        si = ScenarioInfo()
+        si.par["demand"] = make_df("demand")
+
+        # update() fails
+        with pytest.raises(NotImplementedError):
+            ScenarioInfo().update(si)
+
     @pytest.mark.parametrize(
         "codelist, y0, N_all, N_Y, y_m1, dp_checks",
         [
@@ -136,3 +150,26 @@ class TestScenarioInfo:
 
         assert 3 == len(caplog.messages)
         assert all(msg.startswith("Discard existing") for msg in caplog.messages)
+
+
+class TestSpec:
+    def test_getitem(self):
+        s = Spec()
+        with pytest.raises(KeyError):
+            s["foo"]
+
+    def test_setitem(self):
+        s = Spec()
+        s.add = ScenarioInfo()
+
+        with pytest.raises(KeyError):
+            s["foo"] = ScenarioInfo()
+
+    def test_merge(self):
+        s1 = Spec()
+        s1.add.set["technology"] = ["t1", "t3", "t5"]
+        s2 = Spec()
+        s2.add.set["technology"] = ["t2", "t4", "t6"]
+
+        s3 = Spec.merge(s1, s2)
+        assert 6 == len(s3.add.set["technology"])
