@@ -15,21 +15,25 @@ from .common import (
     MESSAGE_MODELS_PATH,
     load_package_data,
     load_private_data,
+    local_data_path,
     package_data_path,
     private_data_path,
 )
 from .node import adapt_R11_R14, identify_nodes
+from .scenarioinfo import ScenarioInfo
 
 __all__ = [
     "MESSAGE_DATA_PATH",
     "MESSAGE_MODELS_PATH",
     "adapt_R11_R14",
+    "as_codes",
     "cached",
     "check_support",
     "convert_units",
     "identify_nodes",
     "load_package_data",
     "load_private_data",
+    "local_data_path",
     "maybe_query",
     "package_data_path",
     "private_data_path",
@@ -75,7 +79,7 @@ def add_par_data(
     return total
 
 
-def as_codes(data: Union[List[str], Dict[str, Dict]]) -> List[Code]:
+def as_codes(data: Union[List[str], Dict[str, Union[Dict, Code]]]) -> List[Code]:
     """Convert *data* to a :class:`list` of :class:`.Code` objects.
 
     Various inputs are accepted:
@@ -94,13 +98,18 @@ def as_codes(data: Union[List[str], Dict[str, Dict]]) -> List[Code]:
         raise TypeError(data)
 
     for id, info in data.items():
-        if isinstance(info, str):
+        # Pass through Code; convert other types to dict()
+        if isinstance(info, Code):
+            result[info.id] = info
+            continue
+        elif isinstance(info, str):
             info = dict(name=info)
         elif isinstance(info, Mapping):
             info = copy(info)
         else:
             raise TypeError(info)
 
+        # Create a Code object
         code = Code(
             id=str(id),
             name=info.pop("name", str(id).title()),
@@ -370,7 +379,9 @@ def make_matched_dfs(base, **par_value):
     }
 
 
-def make_source_tech(info, common, **values) -> Dict[str, pd.DataFrame]:
+def make_source_tech(
+    info: Union[message_ix.Scenario, ScenarioInfo], common, **values
+) -> Dict[str, pd.DataFrame]:
     """Return parameter data for a ‘source’ technology.
 
     The technology has no inputs; its output commodity and/or level are determined by
@@ -379,7 +390,7 @@ def make_source_tech(info, common, **values) -> Dict[str, pd.DataFrame]:
 
     Parameters
     ----------
-    info : ScenarioInfo
+    info : .Scenario or .ScenarioInfo
     common : dict
         Passed to :func:`make_df`.
     **values
@@ -392,6 +403,9 @@ def make_source_tech(info, common, **values) -> Dict[str, pd.DataFrame]:
         Suitable for :func:`add_par_data`.
     """
     # Check arguments
+    if isinstance(info, message_ix.Scenario):
+        info = ScenarioInfo(info)
+
     values.setdefault("capacity_factor", 1.0)
     missing = {"capacity_factor", "output", "var_cost"} - set(values.keys())
     if len(missing):
